@@ -117,13 +117,15 @@ ephy_embed_utils_normalize_address (const char *address)
 	 * auto-search this?" regex in EphyWebView, so we should be a
 	 * valid-ish URL. Auto-prepend http:// to anything that is not
 	 * one according to soup, because it probably will be
-	 * something like "google.com". Special case localhost(:port),
-	 * because SoupURI, correctly, thinks it is a URI with scheme
-	 * being localhost and, optionally, path being the
-	 * port. Ideally we should check if we have a handler for the
-	 * scheme, and since we'll fail for localhost, we'd fallback
-	 * to loading it as a domain. */
-	if (!uri || (uri && !g_strcmp0 (uri->scheme, "localhost")))
+	 * something like "google.com". Special case localhost(:port)
+	 * and IP(:port), because SoupURI, correctly, thinks it is a
+	 * URI with scheme being localhost/IP and, optionally, path
+	 * being the port. Ideally we should check if we have a
+	 * handler for the scheme, and since we'll fail for localhost
+	 * and IP, we'd fallback to loading it as a domain. */
+	if (!uri || 
+	    (uri && !g_strcmp0 (uri->scheme, "localhost")) ||
+	    (uri && g_hostname_is_ip_address (uri->scheme)))
 		effective_address = g_strconcat ("http://", address, NULL);
 	else {
 		/* Convert about: schemes to ephy-about: in order to
