@@ -21,20 +21,20 @@
  */
 
 #include "config.h"
+#include "ephy-lockdown.h"
 
 #include "ephy-action-helper.h"
+#include "ephy-debug.h"
 #include "ephy-embed-container.h"
 #include "ephy-embed-shell.h"
 #include "ephy-embed-utils.h"
-#include "ephy-web-view.h"
-#include "ephy-lockdown.h"
 #include "ephy-extension.h"
-#include "ephy-settings.h"
 #include "ephy-prefs.h"
-#include "ephy-debug.h"
+#include "ephy-private.h"
+#include "ephy-settings.h"
+#include "ephy-web-view.h"
 
 #include <gtk/gtk.h>
-
 #include <string.h>
 
 #define LOCKDOWN_FLAG 1 << 8
@@ -122,8 +122,6 @@ static const BindAction popup_actions[] = {
 };
 
 static const BindAction special_toolbar_actions[] = {
-	{ EPHY_PREFS_LOCKDOWN_ARBITRARY_URL, "Location", "editable" },
-
 	{ EPHY_PREFS_LOCKDOWN_HISTORY, "NavigationBack", "visible" },
 	{ EPHY_PREFS_LOCKDOWN_HISTORY, "NavigationBack", "sensitive" },
 	{ EPHY_PREFS_LOCKDOWN_HISTORY, "NavigationForward", "visible" },
@@ -190,6 +188,16 @@ bind_settings_and_actions (GSettings *settings,
 	}
 }
 
+static void
+bind_location_controller (GSettings *settings,
+			  EphyLocationController *controller)
+{
+	g_settings_bind (settings, EPHY_PREFS_LOCKDOWN_ARBITRARY_URL,
+			 controller, "editable",
+			 G_SETTINGS_BIND_GET |
+			 G_SETTINGS_BIND_INVERT_BOOLEAN);
+}
+
 static void
 impl_attach_window (EphyExtension *extension,
 		    EphyWindow *window)
@@ -198,6 +206,7 @@ impl_attach_window (EphyExtension *extension,
 	GtkActionGroup *action_group;
 	GtkAction *action;
 	GSettings *settings;
+	EphyLocationController *location_controller;
 
 	g_signal_connect (EPHY_SETTINGS_LOCKDOWN,
 			  "changed::" EPHY_PREFS_LOCKDOWN_FULLSCREEN,
@@ -234,6 +243,9 @@ impl_attach_window (EphyExtension *extension,
 	bind_settings_and_actions (EPHY_SETTINGS_LOCKDOWN,
 				   action_group, special_toolbar_actions,
 				   G_N_ELEMENTS (special_toolbar_actions));
+
+	location_controller = ephy_window_get_location_controller (window);
+	bind_location_controller (EPHY_SETTINGS_LOCKDOWN, location_controller);
 }
 
 static void
