@@ -56,6 +56,8 @@ static const SchemeTest tests_no_scheme[] = {
   { "mailto", "mailto:rupert@gnome.org" },
   { "hostname", "localhost" },
   { "hostname_with_port", "localhost:8080" },
+  { "ip_address", "192.168.0.1" },
+  { "ip_address_with_port", "192.168.0.1:8080" },
   { "http_no_double_colon", "http//www.gnome.org/" },
 #if 0
   { "double_colon_first", ":var a=b;" },
@@ -70,9 +72,10 @@ static const SchemeTest tests_no_scheme[] = {
 static const NormalizeTest tests_normalize[] = {
   { "append_http_to_domain", "gnome.org", "http://gnome.org" },
   { "append_http_to_www", "www.gnome.org", "http://www.gnome.org" },
-  { "append_http_to_domain_port", "gnome.org:80", "http://gnome.org:80" },
   { "append_http_to_hostname", "gnome", "http://gnome" },
   { "append_http_to_hostname_with_port", "localhost:8080", "http://localhost:8080" },
+  { "append_http_to_ip_address", "192.168.0.1", "http://192.168.0.1" },
+  { "append_http_to_ip_address_with_port", "192.168.0.1:8080", "http://192.168.0.1:8080" },
   { "convert_about_to_ephy_about", "about:epiphany", "ephy-about:epiphany" },
   { "untouched_http", "http://gnome.org", "http://gnome.org" },
 };
@@ -142,8 +145,8 @@ main (int argc, char *argv[])
     test_name = g_strconcat ("/embed/ephy-embed-utils/normalize_",
                              test.name, NULL);
 
-    g_test_add_data_func (test_name, &test,
-                          (GTestDataFunc) test_normalize_address);
+    g_test_add_data_func (test_name, tests_normalize + i,
+                          (GTestDataFunc)test_normalize_address);
 
     g_free (test_name);
   }
